@@ -1,6 +1,6 @@
 from setuptools import find_packages
+from starterpyth.log import display, GREEN
 from starterpyth.core import load_module
-from starterpyth.log import green
 
 __author__ = 'd9pouces'
 
@@ -49,5 +49,5 @@ class CompileMessages(Command):
                 os.makedirs(os.path.dirname(mo_file))
             if os.path.isfile(po_file):
                 cmd = 'msgfmt --output-file %s %s' % (mo_file, po_file)
-                print(green(_('Processing file %(filename)s.') % {'filename': po_file}))
+                display(_('Processing file %(filename)s.') % {'filename': po_file}, color=GREEN)
                 subprocess.check_call(cmd, shell=True, stderr=subprocess.PIPE)
