@@ -1,7 +1,8 @@
 import os
 from setuptools import find_packages
+from starterpyth.log import display
+from starterpyth.log import GREEN, YELLOW
 from starterpyth.core import load_module
-from starterpyth.log import green, yellow
 
 __author__ = 'd9pouces'
 from distutils.core import Command
@@ -22,7 +23,7 @@ class DocTest(Command):
         module_names = find_packages()
         for module_name in module_names:
             module = load_module(module_name)
-            print(green('Processing %s.' % module_name))
+            display('Processing %s.' % module_name, color=YELLOW)
             doctest.testmod(module)
             module_root = os.path.dirname(module.__file__)
             for filename in os.listdir(module_root):
@@ -32,7 +33,7 @@ class DocTest(Command):
                 submodule_name = '%s.%s' % (module_name, basename)
                 try:
                     module = load_module(submodule_name)
-                    print(green('Processing %s.' % submodule_name))
+                    display('Processing %s.' % submodule_name, color=GREEN)
                     doctest.testmod(module)
                 except ImportError:
-                    print(yellow('Unable to import %s.' % submodule_name))
+                    display('Unable to import %s.' % submodule_name, color=YELLOW)
